@@ -1,5 +1,7 @@
 """Define a base client for interacting with Notion."""
-from typing import Any, Dict, Optional
+from __future__ import annotations
+
+from typing import Any
 
 from aiohttp import ClientSession, ClientTimeout
 from aiohttp.client_exceptions import ClientError
@@ -19,10 +21,14 @@ DEFAULT_TIMEOUT: int = 10
 class Client:  # pylint: disable=too-few-public-methods
     """Define the API object."""
 
-    def __init__(self, *, session: Optional[ClientSession] = None) -> None:
-        """Initialize."""
-        self._session: Optional[ClientSession] = session
-        self._token: Optional[str] = None
+    def __init__(self, *, session: ClientSession | None = None) -> None:
+        """Initialize.
+
+        Args:
+            session: An optional aiohttp ClientSession.
+        """
+        self._session = session
+        self._token: str | None = None
 
         self.bridge = Bridge(self._request)
         self.device = Device(self._request)
@@ -31,25 +37,34 @@ class Client:  # pylint: disable=too-few-public-methods
         self.task = Task(self._request)
 
     async def _request(
-        self, method: str, endpoint: str, **kwargs: Dict[str, Any]
-    ) -> Dict[str, Any]:
-        """Make an API request."""
+        self, method: str, endpoint: str, **kwargs: dict[str, Any]
+    ) -> dict[str, Any]:
+        """Make an API request.
+
+        Args:
+            method: An HTTP method.
+            endpoint: A relative API endpoint.
+            **kwargs: Additional kwargs to send with the request.
+
+        Returns:
+            An API response payload.
+
+        Raises:
+            InvalidCredentialsError: Raised upon invalid credentials.
+            RequestError: Raised upon an underlying HTTP error.
+        """
         url: str = f"{API_BASE}/{endpoint}"
 
         kwargs.setdefault("headers", {})
         if self._token:
             kwargs["headers"]["Authorization"] = f"Token token={self._token}"
 
-        use_running_session = self._session and not self._session.closed
-
-        if use_running_session:
+        if use_running_session := self._session and not self._session.closed:
             session = self._session
         else:
             session = ClientSession(timeout=ClientTimeout(total=DEFAULT_TIMEOUT))
 
-        assert session
-
-        data: Dict[str, Any] = {}
+        data: dict[str, Any] = {}
 
         try:
             async with session.request(method, url, **kwargs) as resp:
@@ -66,7 +81,12 @@ class Client:  # pylint: disable=too-few-public-methods
         return data
 
     async def async_authenticate(self, email: str, password: str) -> None:
-        """Authenticate the user and retrieve an authentication token."""
+        """Authenticate the user and retrieve an authentication token.
+
+        Args:
+            email: The email address of a Notion account.
+            password: The account password.
+        """
         auth_response = await self._request(
             "post",
             "users/sign_in",
@@ -77,9 +97,18 @@ class Client:  # pylint: disable=too-few-public-methods
 
 
 async def async_get_client(
-    email: str, password: str, *, session: Optional[ClientSession] = None
+    email: str, password: str, *, session: ClientSession | None = None
 ) -> Client:
-    """Return an authenticated API object."""
+    """Return an authenticated API object.
+
+    Args:
+        email: The email address of a Notion account.
+        password: The account password.
+        session: An optional aiohttp ClientSession.
+
+    Returns:
+        An authenticated Client object.
+    """
     client: Client = Client(session=session)
     await client.async_authenticate(email, password)
     return client
